@@ -1,5 +1,5 @@
 """
-Version 0.6.0 (in development)
+Version 0.7.0 (in development)
 ==============================
 PyUnity is a Python implementation of the
 Unity Engine, written in C++. This is just
@@ -20,14 +20,14 @@ use pip::
     > pip install pyunity
 
 Alternatively, you can clone the repository
-`here <https://github.com/rayzchen/pyunity>`_
+`here <https://github.com/pyunity/pyunity>`_
 to build the package from source. Then use
 ``setup.py`` to build. Note that it will install
 Cython to compile.
 
     > python setup.py install
 
-Its only dependencies are PyOpenGL, Pygame,
+Its only dependencies are PyOpenGL, PySDL2,
 GLFW, Pillow and PyGLM.
 
 Importing
@@ -44,9 +44,9 @@ This is the output with debugging::
 
     Loaded config
     Trying GLFW as a window provider
-    GLFW doesn't work, trying Pygame
-    Using window provider Pygame
-    Loaded PyUnity version 0.6.0
+    GLFW doesn't work, trying PySDL2
+    Using window provider PySDL2
+    Loaded PyUnity version 0.7.0
 
 If debugging is off, there is no output:
 
@@ -82,7 +82,7 @@ To see what you have added to the scene, call ``scene.List()``:
     /Cube
 
 Finally, to run the scene, call ``scene.Run()``. The window that
-is created is one of FreeGLUT, GLFW or Pygame. The window is
+is created is one of FreeGLUT, GLFW or PySDL2. The window is
 selected on module initialization (see Windows subheading).
 
 Behaviours
@@ -98,11 +98,11 @@ parameter, ``dt``, which is the same as ``Time.deltaTime``.
 Windows
 -------
 The window is provided by one of three
-providers: GLFW, Pygame and FreeGLUT.
+providers: GLFW, PySDL2 and FreeGLUT.
 When you first import PyUnity, it checks
 to see if any of the three providers
 work. The testing order is as above, so
-Pygame is tested last.
+FreeGLUT is tested last.
 
 To create your own provider, create a
 class that has the following methods:
@@ -127,9 +127,9 @@ To run an example, import it like so:
     Loaded config
     Trying FreeGLUT as a window provider
     FreeGLUT doesn't work, trying GLFW
-    GLFW doesn't work, trying Pygame
-    Using window provider Pygame
-    Loaded PyUnity version 0.6.0
+    GLFW doesn't work, trying PySDL2
+    Using window provider PySDL2
+    Loaded PyUnity version 0.7.0
     >>> main()
 
 Or from the command line::
@@ -144,13 +144,13 @@ create a new pull request.
 
 """
 
+import os
 from . import logger as Logger  # lgtm[py/import-own-module]
 from .audio import *
 from .core import *
-from .script import Behaviour
-from . import loader as Loader  # lgtm[py/import-own-module]
 from . import input as Input  # lgtm[py/import-own-module]
-from .input import KeyCode
+from . import loader as Loader  # lgtm[py/import-own-module]
+from .input import KeyCode, KeyState
 from .physics import *
 from .errors import *
 from .files import *
@@ -159,24 +159,30 @@ from .quaternion import Quaternion
 from .vector3 import Vector3
 from .meshes import Mesh
 
-__version__ = "0.6.0"
+__version__ = "0.7.0"
 __copyright__ = "Copyright 2020-2021 Ray Chen"
 __email__ = "tankimarshal2@gmail.com"
 __license__ = "MIT License"
-__summary__ = "A Python implementation of the Unity Engine that supports different types of windows."
+__summary__ = "A Python implementation of the Unity Engine"
 __title__ = "pyunity"
 __uri__ = "https://pyunity.readthedocs.io/en/latest/"
 
-from . import audio, core, physics, errors, files
-__all__ = ["__version__", "Vector3", "Quaternion",
-           "SceneManager", "Mesh", "Loader",
-           "Input", "KeyCode", "Logger",
-           "Behaviour"]
-__all__.extend(audio.__all__)
-__all__.extend(core.__all__)
-__all__.extend(physics.__all__)
-__all__.extend(errors.__all__)
-__all__.extend(files.__all__)
+from . import config, window
+
+# __all__ starts here
+__all__ = ["AABBoxCollider", "AudioClip", "AudioListener", "AudioSource",
+           "Behaviour", "Clock", "CollManager", "Collider", "Color",
+           "Component", "ComponentException", "File", "GameObject",
+           "GameObjectException", "Input", "KeyCode", "KeyState",
+           "Light", "Loader", "Logger", "Material", "Mesh", "MeshRenderer",
+           "PhysicMaterial", "Prefab", "Project", "PyUnityException",
+           "Quaternion", "Rigidbody", "SceneManager", "ShowInInspector",
+           "SphereCollider", "Tag", "Texture2D", "Transform",
+           "Vector3", "infinity"]
+# __all__ ends here
+
+if "PYUNITY_TESTING" not in os.environ:
+    config.windowProvider = window.GetWindowProvider()
 
 Logger.LogLine(Logger.DEBUG, "Loaded PyUnity version %s" % __version__)
 Logger.LogSpecial(Logger.INFO, Logger.RUNNING_TIME)
