@@ -1,4 +1,4 @@
-from pyunity import *
+from pyunity import Behaviour, Logger, SceneManager, GameObject, Material, Color, Vector3, MeshRenderer
 import os
 
 class Rotator(Behaviour):
@@ -17,9 +17,9 @@ def main():
 
     house = GameObject("House")
     house.transform.eulerAngles = Vector3(0, 180, 0)
-    renderer = house.AddComponent(MeshRenderer)
+    # renderer = house.AddComponent(MeshRenderer)
     # renderer.mesh = mesh
-    renderer.mat = Material(Color(255, 0, 0))
+    # renderer.mat = Material(Color(255, 0, 0))
     house.AddComponent(Rotator)
 
     scene.Add(house)
