@@ -1,4 +1,5 @@
-from pyunity import *
+from pyunity import Behaviour, Vector3, SceneManager, GameObject, Mesh, Material, Color, Texture2D, MeshRenderer
+import os
 
 class Rotator(Behaviour):
     def Update(self, dt):
@@ -10,9 +11,11 @@ def main():
     scene.mainCamera.transform.localPosition = Vector3(0, 0, -10)
 
     cube = GameObject("Cube")
+    texture = Texture2D(os.path.join(
+        os.path.dirname(os.path.abspath(__file__)), "logo.png"))
     renderer = cube.AddComponent(MeshRenderer)
     renderer.mesh = Mesh.cube(2)
-    renderer.mat = Material(Color(255, 255, 255), Texture2D("..\\pyunity.png"))
+    renderer.mat = Material(Color(255, 255, 255), texture)
     cube.AddComponent(Rotator)
 
     scene.Add(cube)
