@@ -1,16 +1,12 @@
 """
-pyunity.window
-==============
 A module used to load the window providers.
 
-Windows
--------
 The window is provided by one of three
-providers: GLFW, Pygame and FreeGLUT.
+providers: GLFW, PySDL2 and GLUT.
 When you first import PyUnity, it checks
 to see if any of the three providers
 work. The testing order is as above, so
-FreeGLUT is tested last.
+GLUT is tested last.
 
 To create your own provider, create a
 class that has the following methods:
@@ -29,47 +25,66 @@ pull request.
 
 """
 
-from .pygameWindow import Window as pygameWindow
-from .glfwWindow import Window as glfwWindow
-from .glutWindow import Window as glutWindow
 from ..errors import *
 from .. import Logger
+from .. import config
 import os
-import OpenGL.GLUT
-import glfw
-import pygame
-glfw.ERROR_REPORTING = True
+import pkgutil
+import importlib
 
-
-window_providers = {"FreeGLUT": glutWindow,
-                    "GLFW": glfwWindow, "Pygame": pygameWindow}
+def checkModule(module):
+    if os.getenv("PYUNITY_TESTING") is not None:
+        return
+    if not pkgutil.find_loader(module):
+        raise Exception
 
 def glfwCheck():
     """Checks to see if GLFW works"""
+    checkModule("glfw")
+    import glfw
     if not glfw.init():
         raise Exception
     glfw.create_window(5, 5, "a", None, None)
     glfw.terminate()
 
-def pygameCheck():
-    """Checks to see if Pygame works"""
-    if pygame.init()[0] == 0:
+def sdl2Check():
+    """Checks to see if PySDL2 works"""
+    if not pkgutil.find_loader("sdl2"):
+        raise Exception
+    import sdl2
+    if sdl2.SDL_Init(sdl2.SDL_INIT_VIDEO) != 0:
         raise Exception
 
 def glutCheck():
-    """Checks to see if FreeGLUT works"""
+    """Checks to see if GLUT works"""
+    checkModule("OpenGL.GLUT")
+    import OpenGL.GLUT
     OpenGL.GLUT.glutInit()
 
+
+providers = {
+    "GLFW": ("glfwWindow", glfwCheck),
+    "PySDL2": ("sdl2Window", sdl2Check),
+    "GLUT": ("glutWindow", glutCheck),
+}
+
 def GetWindowProvider():
     """Gets an appropriate window provider to use"""
-    winfo = [
-        ("GLFW", glfwCheck),
-        ("Pygame", pygameCheck),
-        ("FreeGLUT", glutCheck),
-    ]
 
     windowProvider = ""
     i = 0
+    winfo = list(map(lambda x: (x[0], x[1][1]), providers.items()))
+    env = os.getenv("PYUNITY_WINDOW_PROVIDER")
+    if env is not None:
+        env = env.split(",")
+        for specified in reversed(env):
+            if specified not in providers:
+                continue
+            for item in winfo:
+                if item[0] == specified:
+                    selected = item
+            winfo.remove(selected)
+            winfo.insert(0, selected)
 
     for name, checker in winfo:
         next = winfo[i + 1][0] if i < len(winfo) - 1 else None
@@ -91,4 +106,21 @@ def GetWindowProvider():
     if os.environ["PYUNITY_DEBUG_MODE"] == "1":
         Logger.LogLine(Logger.DEBUG, "Using window provider", windowProvider)
 
-    return windowProvider
+    return importlib.import_module("." + providers[windowProvider][0], __name__)
+
+def SetWindowProvider(name):
+    if name not in providers:
+        raise PyUnityException(
+            "No window provider named " + repr(name) + " found")
+    module, checker = providers[name]
+    windowProvider = None
+    try:
+        checker()
+        windowProvider = name
+    except Exception as e:
+        pass
+    if windowProvider is None:
+        raise PyUnityException("Cannot use window provider " + repr(name))
+    window = importlib.import_module("." + module, __name__)
+    config.windowProvider = window
+    return window
